@@ -18,7 +18,8 @@
 #ifndef GPARTED_DIALOG_PARTITION_COPY_H
 #define GPARTED_DIALOG_PARTITION_COPY_H
 
-#include "../include/Dialog_Base_Partition.h"
+#include "Dialog_Base_Partition.h"
+#include "Partition.h"
 
 namespace GParted
 {
@@ -28,10 +29,14 @@ class Dialog_Partition_Copy : public Dialog_Base_Partition
 public:
 	Dialog_Partition_Copy( const FS & fs, const Partition & selected_partition,
 	                       const Partition & copied_partition );
+	~Dialog_Partition_Copy();
 
-	const Partition & Get_New_Partition( Byte_Value sector_size );
+	const Partition & Get_New_Partition();
 
 private:
+	Dialog_Partition_Copy( const Dialog_Partition_Copy & src );              // Not implemented copy constructor
+	Dialog_Partition_Copy & operator=( const Dialog_Partition_Copy & rhs );  // Not implemented copy assignment operator
+
 	void set_data( const Partition & selected_partition, const Partition & copied_partition );
 };
 
