@@ -18,8 +18,9 @@
 #ifndef GPARTED_DIALOG_PARTITION_NEW_H
 #define GPARTED_DIALOG_PARTITION_NEW_H
 
-#include "../include/Dialog_Base_Partition.h"
-#include "../include/Device.h"
+#include "Dialog_Base_Partition.h"
+#include "Device.h"
+#include "Partition.h"
 
 #include <gtkmm/optionmenu.h>
 
@@ -34,9 +35,15 @@ public:
 	                     bool any_extended,
 	                     unsigned short new_count,
 	                     const std::vector<FS> & FILESYSTEMS );
-	const Partition & Get_New_Partition( Byte_Value sector_size );
+	~Dialog_Partition_New();
+
+	const Partition & Get_New_Partition();
 
 private:
+	Dialog_Partition_New( const Dialog_Partition_New & src );              // Not implemented copy constructor
+	Dialog_Partition_New & operator=( const Dialog_Partition_New & rhs );  // Not implemented copy assignment operator
+
+
 	void set_data( const Device & device,
 	               const Partition & partition,
 	               bool any_extended,
