@@ -17,7 +17,9 @@
 #ifndef GPARTED_DIALOG_PARTITION_RESIZE_MOVE_H
 #define GPARTED_DIALOG_PARTITION_RESIZE_MOVE_H
 
-#include "../include/Dialog_Base_Partition.h"
+#include "Dialog_Base_Partition.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -26,12 +28,16 @@ class Dialog_Partition_Resize_Move : public Dialog_Base_Partition
 {
 public:
 	Dialog_Partition_Resize_Move( const FS & fs, const Partition & selected_partition,
-	                              const std::vector <Partition> & partitions );
+	                              const PartitionVector & partitions );
+	~Dialog_Partition_Resize_Move();
 
 private:
-	void set_data( const Partition & selected_partition, const std::vector <Partition> & partitions );
-	void Resize_Move_Normal( const std::vector <Partition> & partitions ) ;
-	void Resize_Move_Extended( const std::vector <Partition> & partitions ) ;
+	Dialog_Partition_Resize_Move( const Dialog_Partition_Resize_Move & src );              // Not implemented copy constructor
+	Dialog_Partition_Resize_Move & operator=( const Dialog_Partition_Resize_Move & rhs );  // Not implemented assignment operator
+
+	void set_data( const Partition & selected_partition, const PartitionVector & partitions );
+	void Resize_Move_Normal( const PartitionVector & partitions );
+	void Resize_Move_Extended( const PartitionVector & partitions );
 };
 
 } //GParted
