@@ -24,7 +24,7 @@
 #ifndef GPARTED_MOUNT_INFO_H
 #define GPARTED_MOUNT_INFO_H
 
-#include "../include/BlockSpecial.h"
+#include "BlockSpecial.h"
 
 #include <glibmm/ustring.h>
 #include <map>
