@@ -17,7 +17,9 @@
 #ifndef GPARTED_OPERATIONDELETE_H
 #define GPARTED_OPERATIONDELETE_H
 
-#include "../include/Operation.h"
+#include "Operation.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -26,14 +28,21 @@ class OperationDelete : public Operation
 {
 public:
 	OperationDelete( const Device & device, const Partition & partition_orig ) ;
-	
-	void apply_to_visual( std::vector<Partition> & partitions ) ;
-		
+	virtual ~OperationDelete();
+
+	void apply_to_visual( PartitionVector & partitions );
+
 private:
+	OperationDelete( const OperationDelete & src );              // Not implemented copy constructor
+	OperationDelete & operator=( const OperationDelete & rhs );  // Not implemented copy assignment operator
+
+	Partition & get_partition_new();
+	const Partition & get_partition_new() const;
+
 	void create_description() ;
 	bool merge_operations( const Operation & candidate );
-	void remove_original_and_adjacent_unallocated( std::vector<Partition> & partitions, int index_orig ) ;
-} ;
+	void remove_original_and_adjacent_unallocated( PartitionVector & partitions, int index_orig );
+};
 
 } //GParted
 
