@@ -33,10 +33,11 @@ namespace GParted
 	
 
 enum PartitionType {
-	TYPE_PRIMARY		=	0,
-	TYPE_LOGICAL		=	1,
-	TYPE_EXTENDED		=	2,
-	TYPE_UNALLOCATED	=	3 
+	TYPE_PRIMARY       = 0,  // Primary partition on a partitioned drive
+	TYPE_LOGICAL       = 1,  // Logical partition on a partitioned drive
+	TYPE_EXTENDED      = 2,  // Extended partition on a partitioned drive
+	TYPE_UNALLOCATED   = 3,  // Unallocated space on a partitioned drive
+	TYPE_UNPARTITIONED = 4   // Unpartitioned whole drive
 };
 
 enum PartitionStatus {
@@ -75,7 +76,6 @@ public:
 	          const Glib::ustring & partition,
 	          int partition_number,
 	          PartitionType type,
-	          bool whole_device,
 	          FILESYSTEM filesystem,
 	          Sector sector_start,
 	          Sector sector_end,
@@ -93,11 +93,16 @@ public:
 	virtual void resize( const Partition & new_size );
 
 	void Set_Unallocated( const Glib::ustring & device_path,
-	                      bool whole_device,
 	                      Sector sector_start,
 	                      Sector sector_end,
 	                      Byte_Value sector_size,
 	                      bool inside_extended );
+	void set_unpartitioned( const Glib::ustring & device_path,
+	                        const Glib::ustring & partition_path,
+	                        FILESYSTEM fstype,
+	                        Sector length,
+	                        Byte_Value sector_size,
+	                        bool busy );
 
 	//update partition number (used when a logical partition is deleted) 
 	void Update_Number( int new_number );
@@ -147,7 +152,6 @@ public:
 	Glib::ustring device_path ;
 	int partition_number;
 	PartitionType type;// UNALLOCATED, PRIMARY, LOGICAL, etc...
-	bool whole_device;  // Is this a virtual partition spanning a whole unpartitioned disk device?
 	PartitionStatus status; //STAT_REAL, STAT_NEW, etc..
 	PartitionAlignment alignment;   //ALIGN_CYLINDER, ALIGN_STRICT, etc
 	FILESYSTEM filesystem ;
