@@ -70,7 +70,7 @@ private:
 	//Fill txtview_device_info_buffer with some information about the selected device
 	void Fill_Label_Device_Info( bool clear = false );
 
-	void Add_Operation( Operation * operation );
+	void Add_Operation( const Device & device, Operation * operation );
 	bool merge_two_operations( unsigned int first, unsigned int second );
 	void merge_operations( MergeType mergetype );
 	void Refresh_Visual();
