@@ -19,10 +19,10 @@
 #ifndef GPARTED_EXT2_H
 #define GPARTED_EXT2_H
 
-#include "../include/FileSystem.h"
-#include "../include/OperationDetail.h"
-#include "../include/Partition.h"
-#include "../include/Utils.h"
+#include "FileSystem.h"
+#include "OperationDetail.h"
+#include "Partition.h"
+#include "Utils.h"
 
 #include <glibmm/ustring.h>
 
@@ -41,7 +41,8 @@ class ext2 : public FileSystem
 	Glib::ustring tune_cmd;
 public:
 	ext2( enum FILESYSTEM type ) : specific_type( type ), dump_cmd( "" ), fsck_cmd( "" ), image_cmd( "" ),
-	                               label_cmd( "" ), mkfs_cmd( "" ), resize_cmd( "" ), tune_cmd( "" ) {};
+	                               label_cmd( "" ), mkfs_cmd( "" ), resize_cmd( "" ), tune_cmd( "" ),
+	                               force_auto_64bit( false ) {};
 	FS get_filesystem_support() ;
 	void set_used_sectors( Partition & partition ) ;
 	void read_label( Partition & partition ) ;
@@ -49,7 +50,7 @@ public:
 	void read_uuid( Partition & partition ) ;
 	bool write_uuid( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
-	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition );
 	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool move( const Partition & partition_new,
 	           const Partition & partition_old,
@@ -65,6 +66,7 @@ private:
 	void copy_progress( OperationDetail *operationdetail );
 
 	Byte_Value fs_block_size;  // Holds file system block size for the copy_progress() callback
+	bool force_auto_64bit;     // Manually setting ext4 64bit feature on creation
 };
 
 } //GParted
