@@ -18,7 +18,8 @@
 #ifndef GPARTED_LVM2_PV_H
 #define GPARTED_LVM2_PV_H
 
-#include "../include/FileSystem.h"
+#include "FileSystem.h"
+#include "Partition.h"
 
 namespace GParted
 {
@@ -31,7 +32,7 @@ public:
 	bool is_busy( const Glib::ustring & path ) ;
 	void set_used_sectors( Partition & partition ) ;
 	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
-	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition );
 	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool remove( const Partition & partition, OperationDetail & operationdetail ) ;
 };
