@@ -18,7 +18,8 @@
 #ifndef GPARTED_NILFS2_H
 #define GPARTED_NILFS2_H
 
-#include "../include/FileSystem.h"
+#include "FileSystem.h"
+#include "Partition.h"
 
 namespace GParted
 {
@@ -33,7 +34,7 @@ public:
 	void read_uuid( Partition & partition ) ;
 	bool write_uuid( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
-	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition );
 };
 
 } //GParted
