@@ -19,7 +19,8 @@
 #ifndef GPARTED_NTFS_H
 #define GPARTED_NTFS_H
 
-#include "../include/FileSystem.h"
+#include "FileSystem.h"
+#include "Partition.h"
 
 namespace GParted
 {
@@ -35,7 +36,7 @@ public:
 	void read_uuid( Partition & partition ) ;
 	bool write_uuid( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
-	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition );
 	bool copy( const Partition & src_part, 
 		   Partition & dest_part,
 		   OperationDetail & operationdetail ) ;
@@ -45,6 +46,7 @@ public:
 
 private:
 	void resize_progress( OperationDetail *operationdetail );
+	void clone_progress( OperationDetail *operationdetail );
 };
 
 } //GParted
