@@ -151,7 +151,7 @@ int DMRaid::execute_command( const Glib::ustring & command, OperationDetail & op
 
 	operationdetail .add_child( OperationDetail( command, STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
 
-	int exit_status = Utils::execute_command( "nice -n 19 " + command, output, error ) ;
+	int exit_status = Utils::execute_command( command, output, error );
 
 	if ( ! output .empty() )
 		operationdetail .get_last_child() .add_child( OperationDetail( output, STATUS_NONE, FONT_ITALIC ) ) ;
@@ -246,9 +246,11 @@ Glib::ustring DMRaid::get_udev_dm_name( const Glib::ustring & dev_path )
 	Glib::ustring dm_name = "" ;
 
 	if ( udevinfo_found )
-		Utils::execute_command( "udevinfo --query=all --name=" + dev_path, output, error, true ) ;
+		Utils::execute_command( "udevinfo --query=all --name=" + Glib::shell_quote( dev_path ),
+		                        output, error, true );
 	else if ( udevadm_found )
-		Utils::execute_command( "udevadm info --query=all --name=" + dev_path, output, error, true ) ;
+		Utils::execute_command( "udevadm info --query=all --name=" + Glib::shell_quote( dev_path ),
+		                        output, error, true );
 
 	if ( ! output .empty() )
 	{
@@ -320,7 +322,6 @@ bool DMRaid::create_dev_map_entries( const Partition & partition, OperationDetai
 {
 	//Create all missing dev mapper entries for a specified device.
 
-	Glib::ustring command ;
 	bool exit_status = true ;
 
 	/*TO TRANSLATORS: looks like  create missing /dev/mapper entries */ 
@@ -328,16 +329,9 @@ bool DMRaid::create_dev_map_entries( const Partition & partition, OperationDetai
 	operationdetail .add_child( OperationDetail( tmp ) );
 
 	//Newer dmraid defaults to always inserting the letter 'p' between the device name
-	//  and the partition number.  Since the '-P' option is not valid for older dmraid
-	//  versions, try with and without the '-P' option.
-	command = "dmraid -ay -P \"\" -v" ;
-	if ( execute_command( command, operationdetail .get_last_child() ) )
-	{
-		//Above command failed, so try without the '-P' option.
-		command = "dmraid -ay -v" ;
-		if ( execute_command( command, operationdetail .get_last_child() ) )
-			exit_status = false ;	//command failed
-	}
+	//  and the partition number.
+	if ( execute_command( "dmraid -ay -P \"\" -v", operationdetail.get_last_child() ) )
+		exit_status = false;  // command failed
 
 	operationdetail .get_last_child() .set_status( exit_status ? STATUS_SUCCES : STATUS_ERROR ) ;
 
@@ -348,20 +342,13 @@ bool DMRaid::create_dev_map_entries( const Glib::ustring & dev_path )
 {
 	//Create all missing dev mapper entries for a specified device.
 
-	Glib::ustring command, output, error ;
+	Glib::ustring output, error ;
 	bool exit_status = true ;
 
 	//Newer dmraid defaults to always inserting the letter 'p' between the device name
-	//  and the partition number.  Since the '-P' option is not valid for older dmraid
-	//  versions, try with and without the '-P' option.
-	command = "dmraid -ay -P \"\" -v" ;
-	if ( Utils::execute_command( command, output, error, true ) )
-	{
-		//Above command failed, so try without the '-P' option.
-		command = "dmraid -ay -v" ;
-		if ( Utils::execute_command( command, output, error, true ) )
-			exit_status = false;	//command failed
-	}
+	//  and the partition number.
+	if ( Utils::execute_command( "dmraid -ay -P \"\" -v", output, error, true ) )
+		exit_status = false;  // command failed
 
 	return exit_status ;
 }
@@ -430,7 +417,7 @@ bool DMRaid::delete_affected_dev_map_entries( const Partition & partition, Opera
 
 	for ( unsigned int k=0; k < affected_entries .size(); k++ )
 	{
-		command = "dmsetup remove " + DEV_MAPPER_PATH + affected_entries[k];
+		command = "dmsetup remove " + Glib::shell_quote( DEV_MAPPER_PATH + affected_entries[k] );
 		if ( execute_command( command, operationdetail .get_last_child() ) )
 			exit_status = false ;	//command failed
 	}
@@ -454,7 +441,7 @@ bool DMRaid::delete_dev_map_entry( const Partition & partition, OperationDetail
 	
 	for ( unsigned int k = 0; k < partition_entries .size(); k++ )
 	{
-		Glib::ustring command = "dmsetup remove " + partition_entries[k] ;
+		Glib::ustring command = "dmsetup remove " + Glib::shell_quote( partition_entries[k] );
 		if ( execute_command( command, operationdetail .get_last_child() ) )
 			exit_status = false ;	//command failed
 	}
@@ -477,7 +464,7 @@ bool DMRaid::purge_dev_map_entries( const Glib::ustring & dev_path )
 
 	for ( unsigned int k=0; k < dir_list .size(); k++ )
 	{
-		command = "dmsetup remove " + DEV_MAPPER_PATH + dir_list[k];
+		command = "dmsetup remove " + Glib::shell_quote( DEV_MAPPER_PATH + dir_list[k] );
 		if ( Utils::execute_command( command, output, error, true ) )
 			exit_status = false ;	//command failed
 	}
