@@ -13,8 +13,9 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#include "../include/DialogManageFlags.h"
+
+#include "DialogManageFlags.h"
+#include "Partition.h"
 
 #include <gtkmm/main.h>
 #include <gtkmm/stock.h>
