@@ -24,7 +24,7 @@ Dialog_FileSystem_Label::Dialog_FileSystem_Label( const Partition & partition )
 {
 	this ->set_resizable( false ) ;
 	this ->set_has_separator( false ) ;
-	this ->set_size_request( 300, 80 ) ;
+	this->set_size_request( 400, -1 );
 
 	/* TO TRANSLATORS: dialog title, looks like   Set file system label on /dev/hda3 */
 	this->set_title( String::ucompose( _("Set file system label on %1"), partition.get_path() ) );
@@ -45,7 +45,7 @@ Dialog_FileSystem_Label::Dialog_FileSystem_Label( const Partition & partition )
 		//Create Text entry box
 		entry = manage(new Gtk::Entry());
 		entry->set_max_length( Utils::get_filesystem_label_maxlength( partition.filesystem ) ) ;
-		entry->set_width_chars(20);
+		entry->set_width_chars( 30 );
 		entry->set_activates_default(true);
 		entry->set_text(partition.get_filesystem_label());
 		entry->select_region(0, entry ->get_text_length());
