@@ -15,8 +15,10 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "../include/Dialog_Partition_Copy.h"
-#include "../include/GParted_Core.h"
+#include "Dialog_Partition_Copy.h"
+#include "GParted_Core.h"
+#include "Partition.h"
+#include "Utils.h"
 
 namespace GParted
 {
@@ -32,13 +34,20 @@ Dialog_Partition_Copy::Dialog_Partition_Copy( const FS & fs, const Partition & s
 	set_data( selected_partition, copied_partition );
 }
 
+Dialog_Partition_Copy::~Dialog_Partition_Copy()
+{
+	delete new_partition;
+	new_partition = NULL;
+}
+
 void Dialog_Partition_Copy::set_data( const Partition & selected_partition, const Partition & copied_partition )
 {
 	this ->set_title( String::ucompose( _("Paste %1"), copied_partition .get_path() ) ) ;
 	
 	//set partition color
-	frame_resizer_base ->set_rgb_partition_color( copied_partition .color ) ;
-	
+	Gdk::Color partition_color( Utils::get_color( copied_partition.filesystem ) );
+	frame_resizer_base->set_rgb_partition_color( partition_color );
+
 	//set some widely used values...
 	MIN_SPACE_BEFORE_MB = Dialog_Base_Partition::MB_Needed_for_Boot_Record( selected_partition ) ;
 	START = selected_partition .sector_start ;
@@ -101,12 +110,13 @@ void Dialog_Partition_Copy::set_data( const Partition & selected_partition, cons
 	               ) ;
 
 	// Set member variable used in Dialog_Base_Partition::prepare_new_partition()
-	new_partition = copied_partition;
-	new_partition.device_path     = selected_partition.device_path;
-	new_partition.inside_extended = selected_partition.inside_extended;
-	new_partition.type            = selected_partition.inside_extended ? TYPE_LOGICAL : TYPE_PRIMARY;
+	new_partition = copied_partition.clone();
+	new_partition->device_path     = selected_partition.device_path;
+	new_partition->inside_extended = selected_partition.inside_extended;
+	new_partition->type            = selected_partition.inside_extended ? TYPE_LOGICAL : TYPE_PRIMARY;
+	new_partition->sector_size     = selected_partition.sector_size;
 	//Handle situation where src sector size is smaller than dst sector size and an additional partial dst sector is required.
-	new_partition.set_sector_usage(
+	new_partition->set_sector_usage(
 			(   ( ( copied_partition .sectors_used + copied_partition .sectors_unused ) * copied_partition .sector_size )
 			  + ( selected_partition .sector_size - 1 )
 			) / selected_partition .sector_size,
@@ -117,15 +127,17 @@ void Dialog_Partition_Copy::set_data( const Partition & selected_partition, cons
 	this ->show_all_children() ;
 }
 
-const Partition & Dialog_Partition_Copy::Get_New_Partition( Byte_Value sector_size )
+const Partition & Dialog_Partition_Copy::Get_New_Partition()
 {
+	g_assert( new_partition != NULL );  // Bug: Not initialised by constructor calling set_data()
+
 	//first call baseclass to get the correct new partition
-	Dialog_Base_Partition::prepare_new_partition( sector_size );
+	Dialog_Base_Partition::prepare_new_partition();
 
 	//set proper name and status for partition
-	new_partition.status = STAT_COPY;
+	new_partition->status = STAT_COPY;
 
-	return new_partition;
+	return *new_partition;
 }
 
 } //GParted
