@@ -182,9 +182,10 @@ void Dialog_Rescue_Data::on_view_clicked(int nPart)
 
 	Glib::ustring mountPoint=tmpDir;
 
-	Glib::ustring commandLine= "mount -o ro,loop,offset="+Utils::num_to_str(initOffset)
-		+",sizelimit="+Utils::num_to_str(totalSize)+" "+this->device_path+" \""+mountPoint+"\"";
-
+	Glib::ustring commandLine = "mount -o ro,loop,offset=" + Utils::num_to_str(initOffset) +
+	                            ",sizelimit=" + Utils::num_to_str(totalSize) +
+	                            " " + Glib::shell_quote(this->device_path) +
+	                            " " + Glib::shell_quote(mountPoint);
 	int mountResult=Utils::execute_command(commandLine);
 
 	if(mountResult!=0)
@@ -279,7 +280,7 @@ void Dialog_Rescue_Data::check_overlaps(int nPart)
 			{
 				Glib::ustring mountP=this->device->partitions[i].get_mountpoint();
 
-				Glib::ustring commandUmount = "umount \"" + mountP + "\"";
+				Glib::ustring commandUmount = "umount " + Glib::shell_quote(mountP);
 				Utils::execute_command(commandUmount);
 			}
 		}
@@ -430,7 +431,7 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 
 			Partition * part = new Partition();
 			part->Set( dev_path, part_path, part_num,
-			           type, false, fs, sec_start, sec_end, sec_size, false, false );
+			           type, fs, sec_start, sec_end, sec_size, false, false );
 			this->partitions.push_back_adopt( part );
 		}
 	}
