@@ -14,9 +14,9 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "../include/OperationCheck.h"
-#include "../include/Partition.h"
-#include "../include/PartitionVector.h"
+#include "OperationCheck.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -27,28 +27,15 @@ OperationCheck::OperationCheck( const Device & device, const Partition & partiti
 
 	this->device = device.get_copy_without_partitions();
 	this->partition_original = partition.clone();
+	this->partition_new      = partition.clone();
 }
 
 OperationCheck::~OperationCheck()
 {
 	delete partition_original;
+	delete partition_new;
 	partition_original = NULL;
-}
-
-Partition & OperationCheck::get_partition_new()
-{
-	g_assert( false );  // Bug: OperationCheck class doesn't use partition_new
-
-	// Not reached.  Return value to keep compiler quiet.
-	return *partition_new;
-}
-
-const Partition & OperationCheck::get_partition_new() const
-{
-	g_assert( false );  // Bug: OperationCheck class doesn't use partition_new
-
-	// Not reached.  Return value to keep compiler quiet.
-	return *partition_new;
+	partition_new = NULL;
 }
 
 void OperationCheck::apply_to_visual( PartitionVector & partitions )
@@ -61,7 +48,7 @@ void OperationCheck::create_description()
 
 	/*TO TRANSLATORS: looks like  Check and repair file system (ext3) on /dev/hda4 */
 	description = String::ucompose( _("Check and repair file system (%1) on %2"),
-	                                Utils::get_filesystem_string( partition_original->filesystem ),
+	                                partition_original->get_filesystem_string(),
 	                                partition_original->get_path() );
 }
 
