@@ -45,19 +45,19 @@ void OperationFormat::apply_to_visual( PartitionVector & partitions )
 	g_assert( partition_original != NULL );  // Bug: Not initialised by constructor or reset later
 	g_assert( partition_new != NULL );  // Bug: Not initialised by constructor or reset later
 
-	if ( partition_original->whole_device && partition_new->filesystem == FS_CLEARED )
+	if ( partition_original->type == TYPE_UNPARTITIONED && partition_new->filesystem == FS_CLEARED )
 	{
 		// Make format to cleared whole disk device file system preview as
 		// unallocated device, matching what happens when implemented.
 		partitions.clear();
 
 		Partition * temp_partition = new Partition();
-		temp_partition->Set_Unallocated( device.get_path(),
-		                                 true,
-		                                 0LL,
-		                                 device.length -1LL,
-		                                 device.sector_size,
-		                                 false );
+		temp_partition->set_unpartitioned( device.get_path(),
+		                                   "",  // Overridden with "unallocated"
+		                                   FS_UNALLOCATED,
+		                                   device.length,
+		                                   device.sector_size,
+		                                   false );
 		partitions.push_back_adopt( temp_partition );
 	}
 	else
