@@ -14,9 +14,9 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "../include/OperationLabelFileSystem.h"
-#include "../include/Partition.h"
-#include "../include/PartitionVector.h"
+#include "OperationLabelFileSystem.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -49,7 +49,7 @@ void OperationLabelFileSystem::create_description()
 {
 	g_assert( partition_new != NULL );  // Bug: Not initialised by constructor or reset later
 
-	if( partition_new->get_filesystem_label().empty() )
+	if( partition_new->get_filesystem_partition().get_filesystem_label().empty() )
 	{
 		/* TO TRANSLATORS: looks like   Clear file system Label on /dev/hda3 */
 		description = String::ucompose( _("Clear file system label on %1"),
@@ -59,7 +59,7 @@ void OperationLabelFileSystem::create_description()
 	{
 		/* TO TRANSLATORS: looks like   Set file system label "My Label" on /dev/hda3 */
 		description = String::ucompose( _("Set file system label \"%1\" on %2"),
-		                                partition_new->get_filesystem_label(),
+		                                partition_new->get_filesystem_partition().get_filesystem_label(),
 		                                partition_new->get_path() );
 	}
 }
