@@ -40,7 +40,6 @@ void Partition::Reset()
 	messages .clear() ;
 	status = GParted::STAT_REAL ;
 	type = GParted::TYPE_UNALLOCATED ;
-	whole_device = false;
 	alignment = ALIGN_STRICT ;
 	filesystem = GParted::FS_UNALLOCATED ;
 	have_filesystem_label = false;
@@ -62,7 +61,6 @@ void Partition::Set( const Glib::ustring & device_path,
                      const Glib::ustring & partition,
                      int partition_number,
                      PartitionType type,
-                     bool whole_device,
                      FILESYSTEM filesystem,
                      Sector sector_start,
                      Sector sector_end,
@@ -74,7 +72,6 @@ void Partition::Set( const Glib::ustring & device_path,
 	this->path = partition;
 	this ->partition_number = partition_number;
 	this ->type = type;
-	this->whole_device = whole_device;
 	this ->filesystem = filesystem;
 	this ->sector_start = sector_start;
 	this ->sector_end = sector_end;
@@ -178,7 +175,6 @@ void Partition::resize( const Partition & new_size )
 }
 
 void Partition::Set_Unallocated( const Glib::ustring & device_path,
-                                 bool whole_device,
                                  Sector sector_start,
                                  Sector sector_end,
                                  Byte_Value sector_size,
@@ -190,7 +186,6 @@ void Partition::Set_Unallocated( const Glib::ustring & device_path,
 	     Utils::get_filesystem_string( FS_UNALLOCATED ),
 	     -1,
 	     TYPE_UNALLOCATED,
-	     whole_device,
 	     FS_UNALLOCATED,
 	     sector_start,
 	     sector_end,
@@ -201,6 +196,37 @@ void Partition::Set_Unallocated( const Glib::ustring & device_path,
 	status = GParted::STAT_REAL ;
 }
 
+void Partition::set_unpartitioned( const Glib::ustring & device_path,
+                                   const Glib::ustring & partition_path,
+                                   FILESYSTEM fstype,
+                                   Sector length,
+                                   Byte_Value sector_size,
+                                   bool busy )
+{
+	Reset();
+	Set( device_path,
+	     // The path from the parent Device object and this child Partition object
+	     // spanning the whole device would appear to be the same.  However the former
+	     // may have come from the command line and the later is the canonicalised
+	     // name returned from libparted.  (See GParted_Core::set_device_from_disk()
+	     // "loop" table and GParted_Core::set_device_one_partition() calls to
+	     // set_unpartitioned()).  Therefore they can be different.
+	     //
+	     // For unrecognised whole disk device partitions use "unallocated" as the
+	     // partition path to match what Set_Unallocated() does when it created such
+	     // whole disk device partitions.
+	     ( fstype == FS_UNALLOCATED ) ? Utils::get_filesystem_string( FS_UNALLOCATED )
+	                                  : partition_path,
+	     1,
+	     TYPE_UNPARTITIONED,
+	     fstype,
+	     0LL,
+	     length - 1LL,
+	     sector_size,
+	     false,
+	     busy );
+}
+
 void Partition::Update_Number( int new_number )
 {  
 	unsigned int index = path.rfind( Utils::num_to_str( partition_number ) );
