@@ -14,16 +14,14 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-
-#include "../include/exfat.h"
+#include "exfat.h"
 
 namespace GParted
 {
 
 FS exfat::get_filesystem_support()
 {
-	FS fs ;
-	fs .filesystem = FS_EXFAT ;
+	FS fs( FS_EXFAT );
 
 	fs .busy = FS::GPARTED ;
 	fs .copy = FS::GPARTED ;
