@@ -14,17 +14,15 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
- 
-#include "../include/ufs.h"
+
+#include "ufs.h"
 
 namespace GParted
 {
 
 FS ufs::get_filesystem_support()
 {
-	FS fs ;
-	fs .filesystem = GParted::FS_UFS ;
+	FS fs( FS_UFS );
 
 	fs .busy = FS::GPARTED ;
 	fs .copy = GParted::FS::GPARTED ;
